#
# Conditional build:
%bcond_without	python2	# Python 2.x modules
%bcond_without	python3	# Python 3.x modules
%bcond_without	tests	# unit tests
#
# NOTE:
# - as we use system tzdata package, keeping this pkg up to the latest is
#   pointless if only data has changed
# - ...but other packages may require newer version anyway, through egg dependencies
%define 	module		pytz
# pytz/__init__.py /OLSON_VERSION
%define 	olsonver	2020a
Summary:	pytz - Olson timezone database in Python
Summary(pl.UTF-8):	pytz - baza stref czasowych Olsona w Pythonie
Name:		python-%{module}
Version:	2020.1
Release:	1
License:	MIT or ZPL v2.1
Group:		Libraries/Python
#Source0Download: https://pypi.org/simple/pytz/
Source0:	https://files.pythonhosted.org/packages/source/p/pytz/pytz-%{version}.tar.gz
# Source0-md5:	0349106ac02f2bfe565dd6d5594e3a15
Patch0:		zoneinfo.patch
URL:		http://pytz.sourceforge.net/
BuildRequires:	rpmbuild(macros) >= 1.714
BuildRequires:	sed >= 4.0
%if %{with python2}
BuildRequires:	python >= 1:2.3
BuildRequires:	python-devel >= 1:2.4
BuildRequires:	python-setuptools
%endif
%if %{with python3}
BuildRequires:	python3-devel >= 1:3.2
BuildRequires:	python3-setuptools
%endif
Requires:	python-modules >= 1:2.4
Requires:	tzdata-zoneinfo >= %{olsonver}
BuildArch:	noarch
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
pytz brings the Olson tz database into Python. This library allows
accurate and cross platform timezone calculations using Python 2.3 or
higher.

%description -l pl.UTF-8
pytz dodaje do Pythona moduł umożliwiający odpytywanie bazy stref
czasowych Olsona. Moduł ten umożliwia przeprowadzanie dokładnych,
niezależnych od platformy obliczeń uwzględniających strefy czasowe
przy użyciu Pythona w wersji co najmniej 2.3.

%package -n python3-%{module}
Summary:	pytz - Olson timezone database in Python 3.x
Summary(pl.UTF-8):	pytz - baza stref czasowych Olsona w Pythonie 3.x
Group:		Libraries/Python
Requires:	python3-modules >= 1:3.2
Requires:	tzdata-zoneinfo >= %{olsonver}

%description -n python3-%{module}
pytz brings the Olson tz database into Python. This library allows
accurate and cross platform timezone calculations using Python 3.x

%description -n python3-%{module} -l pl.UTF-8
pytz dodaje do Pythona moduł umożliwiający odpytywanie bazy stref
czasowych Olsona. Moduł ten umożliwia przeprowadzanie dokładnych,
niezależnych od platformy obliczeń uwzględniających strefy czasowe
przy użyciu Pythona 3.x

%prep
%setup -q -n %{module}-%{version}

# strip zones list before patching
%{__sed} -i -e "/^all_timezones = \\\\/,/^ 'Zulu'/d" \
	-e "/^common_timezones = \\\\/,/ 'UTC'/d" pytz/__init__.py

%patch0 -p1

%build
v=$(sed -rne "s/^OLSON_VERSION = '(.+)'/\1/p" pytz/__init__.py)
test "$v" = "%{olsonver}"

%if %{with python2}
%py_build
%py_lint

%if %{with tests}
%{__python} -munittest discover -s pytz/tests
%endif
%endif

%if %{with python3}
%py3_build

%if %{with tests}
%{__python3} -munittest discover -s pytz/tests
%endif
%endif

%install
rm -rf $RPM_BUILD_ROOT

%if %{with python2}
%py_install

%{__rm} -r $RPM_BUILD_ROOT%{py_sitescriptdir}/pytz/zoneinfo
%py_postclean
%endif

%if %{with python3}
%py3_install

%{__rm} -r $RPM_BUILD_ROOT%{py3_sitescriptdir}/pytz/zoneinfo
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%if %{with python2}
%files
%defattr(644,root,root,755)
%doc LICENSE.txt README.rst
%{py_sitescriptdir}/pytz
%{py_sitescriptdir}/pytz-%{version}-py*.egg-info
%endif

%if %{with python3}
%files -n python3-%{module}
%defattr(644,root,root,755)
%doc LICENSE.txt README.rst
%{py3_sitescriptdir}/pytz
%{py3_sitescriptdir}/pytz-%{version}-py*.egg-info
%endif
%changelog
* Sun Jun 07 2020 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/python-pytz.git;a=log;h=master

* Sun Jun 07 2020 Jakub Bogusz <qboosh@pld-linux.org> 282410c
- updated to 2020.1 (Olson 2020a)

* Sat Dec 28 2019 Jakub Bogusz <qboosh@pld-linux.org> b67ac5d
- updated to 2019.3 (olson 2019c)

* Sat Nov 09 2019 Marcin Krol <hawk@tld-linux.org> 5058ae6
- release 3

* Mon Oct 28 2019 Jan Rękorajski <baggins@pld-linux.org> b064cac
- rebuild with python 3.8
- release 2 (by relup.sh)

* Thu Oct 03 2019 Jakub Bogusz <qboosh@pld-linux.org> 7080d4f
- updated to 2019.2

* Thu Nov 08 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> e0a8fe8
- up to 2018.7

* Wed Jul 18 2018 Jakub Bogusz <qboosh@pld-linux.org> 0b9d783
- updated to 2018.5

* Sun Jul 01 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> 5967bee
- release 2 (by relup.sh)

* Sat May 26 2018 Jakub Bogusz <qboosh@pld-linux.org> db98e45
- updated to 2018.4
- updated zoneinfo patch
- run unit tests

* Wed Dec 28 2016 Arkadiusz Miśkiewicz <arekm@maven.pl> ca950c2
- python 3.6.0 rebuild
- release 2 (by relup.sh)

* Mon Oct 17 2016 Elan Ruusamäe <glen@delfi.ee> fa19a5f
- should require only timezone data

* Mon Oct 17 2016 Elan Ruusamäe <glen@delfi.ee> 59e720f
- verify olson version match

* Mon Oct 17 2016 Elan Ruusamäe <glen@delfi.ee> cea56a3
- up to 2016.7 (2016g)

* Mon Oct 17 2016 Elan Ruusamäe <glen@delfi.ee> 53e277b
- this package versioning is not compatible anymore since 2014.4 (9e927ab2)

* Mon Oct 17 2016 Elan Ruusamäe <glen@delfi.ee> e6b8d84
- use named url from pythonhosted

* Wed Apr 27 2016 Andrzej Zawadzki <zawadaa@pld-linux.org> e4cbdd0
- up to 2016.4

* Fri Jan 29 2016 Arkadiusz Miśkiewicz <arekm@maven.pl> 4ccf24d
- up to 2015.7

* Sun Nov 29 2015 Jacek Konieczny <jajcus@jajcus.net> 051ee27
- BR: rpmbuild(macros) >= 1.710

* Sat Nov 28 2015 Jacek Konieczny <jajcus@jajcus.net> d01ecec
- release 3 (by relup.sh)

* Sat Nov 28 2015 Jacek Konieczny <jajcus@jajcus.net> ed658ad
- automatic change: use py_build/py_install macros

